==> whatap-python-0.1.90.tar.gz: whatap-python-0.1.90/whatap/conf/configuration.py <==
Configuration = {
    "dev": False,
    "net_udp_port": "6600",
    "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, swf, ico",
    "trace_auto_normalize_enabled": True,
    "trace_user_enabled": True,
    "trace_user_using_ip": True,

    "query_string_enabled": False,
    "query_string_urls": "",

    "profile_dbc_close": False,
    "profile_http_header_enabled": False,
    "profile_http_parameter_enabled": False,
    "profile_sql_param_enabled": False,
    "hook_method_patterns": "",

    "mtrace_rate": 0,
    "mtrace_spec": '',
    "mtrace_send_url_length": 80,

    "_trace_mtrace_caller_key": "x-wtap-mst",
    "_trace_mtrace_callee_key": "x-wtap-tx",
    "_trace_mtrace_info_key": "x-wtap-inf",
    "_trace_mtrace_ip": "x-wtap-ip",

    "stat_enabled": False,
    "stat_domain_enabled": False,
    "stat_domain_max_count": 7000,
    "stat_mtrace_enabled": False,
    "stat_mtrace_max_count": 7000,
    "stat_login_enabled": False,
    "stat_login_max_count": 7000,
    "stat_referer_enabled": False,
    "stat_referer_max_count": 7000,

	"stat_tx_max_count": 5000,
	"stat_sql_max_count": 5000,
	"stat_httpc_max_count": 5000,
	"stat_error_max_count": 1000,
	"stat_useragent_max_count": 500,

    "user_header_ticket_enabled": False,
    "user_header_ticket":"",
    "trace_user_cookie_limit":2048,
    "trace_user_cookie_domain":"",
    "profile_exception_stack": False,

    # "whatap_server_host": "127.0.0.1/127.0.0.1",
    # "whatap_server_port": 6600,
    # "mode": "whatap_dev",
    # "debug": False,
    # "license": None,
    # "counter_enabled": True,
    # "stat_enabled": True,
    # "active_stack_enabled": True,
    # "trx_profile_enabled": True,
    # "trx_profile_sql_enabled": True,
    # "trx_profile_httpc_enabled": True,
    # "trx_profile_max_time": 300000,
    # "trx_profile_max_count": 10000,
    # "prepared_sql_max": 5001,
    # "debug_prepared_sql": False,
    # "trace_service_name_header_key": None,
    # "trace_service_name_key": None,
    # "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, txt",
    # "trace_auto_service_enabled": False,
    # "trace_auto_service_backstack_enabled": True,
    # "trace_background_socket_enabled": True,
    # "trace_activeserivce_yellow_time": 3000,
    # "trace_activeservice_red_time": 8000,
    # "trace_activeservice_hang_time": 6000,
    # "trace_intertx_enabled": True,
    # "trace_error_callstack_depth": 50,
    # "trace_active_callstack_depth": 50,
    # "_trace_intertx_caller_pcode_key": "x-wtap-pcode",
    # "_trace_intertx_caller_oid_key": "x-wtap-oid",
    # "_trace_intertx_caller_seq_key": "x-wtap-seq",
    # "_trace_intertx_call_url_key": "x-wtap-url",
    # "trace_httpc_normalize_urls": "",
    # "trace_httpc_normalize_enabled": True,
    # "trace_normalize_enabled": True,
    # "log_ignore_set": None,
    # "tcp_connection_timeout": 60000,
    # "tcp_so_timeout": 60000,
    # "net_send_max_bytes": 5 * 1024 * 1024,
    # "net_send_queue1_size": 512,
    # "net_send_queue2_size": 1024,
    # "hook_connection_open_patterns": "",
    # "log_datasource_lookup_enabled": True,
    # "throttle_enabled": False,
    # "throttle_limit": 10000,
    # "throttle_ignore": ",",
    # "throttle_reject_text": "too many request!!",
    # # "throttle_reject_url": "",
    # # "throttle_reject_url_ok": self.throttle_reject_url == "" ? False : True,
    # "profile_http_querystring_enabled": False,
    # "profile_http_header_enabled": False,
    # "profile_http_parameter_enabled": False,
    # "profile_http_parameter_url_prefix": "/",
    # "profile_http_header_url_prefix": "/",
    # "profile_connection_open_enabled": True,
    # "profile_step_max_count": 1024,
    # "hook_method_patterns": "",
    # "hook_method_access_public_enabled": True,
    # "hook_method_access_protected_enabled": True,
    # "hook_method_access_private_enabled": False,
    # "hook_method_access_none_enabled": True,
    # "hook_method_ignore_prefixes": "get,set",
    # "hook_method_ignore_classes": "",
    # "profile_method_enabled": True,
    # "hook_service_patterns": "",
    # "hook_httpc_patterns": "",
    # "hook_httpc_info_patterns": "",
    # "hook_jdbc_pstmt_classes": "",
    # "hook_jdbc_stmt_classes": "",
    # "hook_jdbc_rs_classes": "",
    # "hook_jdbc_wrapping_driver_patterns": "",
    # "hook_context_classes": "javax/naming/InitialContext",
    # "hook_jsp_patterns": "",
    # "hook_trace_helper_start_patterns": "",
    # "hook_trace_helper_end_patterns": "",
    # "hook_dyna_ignore_count": 100,
    #
    # "profile_fullstack_max_lines": 0,
    #
    # "profile_step_normal_count": 800,
    # "profile_step_heavy_count": 1000,
    # "profile_step_max_count": 1024,
    # "profile_step_heavy_time": 100,
    #
    # "boolean profile_sql_param_enabled": False,
    # "profile_sql_resource_enabled": False,
    # "profile_method_resource_enabled": False,
    # "profile_httpc_resource_enabled": False,
    # "_profile_prepare_sql": False,
    # "profile_dbc_close": False,
    #
    "trace_http_client_ip_header_key": "",
    # "trace_user_enabled": True,
    # "trace_user_using_ip": False,
    # "trace_user_using_type": 1,
    # "trace_user_cookie_limit": 2048,
    # "profile_error_jdbc_fetch_max": 10000,
    # "profile_error_sql_time_max": 30000,
    # "hook_direct_patch_classes": "",
    # "_hook_serivce_enabled": True,
    # "_hook_dbsql_enabled": True,
    # "_hook_dbconn_enabled": True,
    # "_hook_methods_enabled": True,
    # "_hook_socket_enabled": True,
    # "_hook_usertx_enabled": True,
    # "log_rotation_enabled": True,
    # "log_keep_days": 7,
    # "thread_dump_enabled": False,
    # "debug_cpu_enabled": False,
    # "active_stack_always_do": False,
    # "active_stack_callstack_interval_sec": 10,
    # "realtime_interval_ms": 5000,
    # "cipher_net_enabled": True,
    # "cipher_level": 2,
    # 'cypher_level': 128,
    # "boot_redefine_size": 100,
    # "counter_netstat_enabled": False,
    # "counter_procfd_enabled": False,
    # "counter_interval": 5000,
    # "CONFIG_INITED": False,
    # "_profile_position_httpc_hash": 0,
    # "profile_position_httpc": "",
    # "_profile_position_sql_hash": 0,
    # "profile_position_sql": "",
    # "_profile_position_method_hash": 0,
    # "profile_position_method": "",
    # "profile_position_depth": 50,
    # "time_sync_interval_ms": 300000,
    # "trace_active_transaction_yellow_time": 3000,
    # "trace_active_transaction_red_time": 8000,
    # "trace_active_transaction_hang_time": 30000,
    # "realtime_user_thinktime_max": 300000,
    # "service_port_enabled": False,
    # 'log_pack_data': False,
    # "active_stack_second": 10
}

==> whatap-python-0.1.107.tar.gz: whatap-python-0.1.107/whatap/conf/configuration.py <==
Configuration = {
    "dev": False,
    "net_udp_port": "6600",
    "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, swf, ico",
    "trace_auto_normalize_enabled": True,
    "trace_user_enabled": True,
    "trace_user_using_ip": True,

    "query_string_enabled": False,
    "query_string_urls": "",

    "profile_dbc_close": False,
    "profile_http_header_enabled": False,
    "profile_http_parameter_enabled": False,
    "profile_sql_param_enabled": False,
    "hook_method_patterns": "",

    "mtrace_rate": 0,
    "mtrace_spec": '',
    "mtrace_send_url_length": 80,

    "_trace_mtrace_caller_key": "x-wtap-mst",
    "_trace_mtrace_callee_key": "x-wtap-tx",
    "_trace_mtrace_info_key": "x-wtap-inf",
    "_trace_mtrace_ip": "x-wtap-ip",

    "stat_enabled": False,
    "stat_domain_enabled": False,
    "stat_domain_max_count": 7000,
    "stat_mtrace_enabled": False,
    "stat_mtrace_max_count": 7000,
    "stat_login_enabled": False,
    "stat_login_max_count": 7000,
    "stat_referer_enabled": False,
    "stat_referer_max_count": 7000,

	"stat_tx_max_count": 5000,
	"stat_sql_max_count": 5000,
	"stat_httpc_max_count": 5000,
	"stat_error_max_count": 1000,
	"stat_useragent_max_count": 500,

    "user_header_ticket_enabled": False,
    "user_header_ticket":"",
    "trace_user_cookie_limit":2048,
    "trace_user_cookie_domain":"",
    "profile_exception_stack": False,

    # "whatap_server_host": "127.0.0.1/127.0.0.1",
    # "whatap_server_port": 6600,
    # "mode": "whatap_dev",
    # "debug": False,
    # "license": None,
    # "counter_enabled": True,
    # "stat_enabled": True,
    # "active_stack_enabled": True,
    # "trx_profile_enabled": True,
    # "trx_profile_sql_enabled": True,
    # "trx_profile_httpc_enabled": True,
    # "trx_profile_max_time": 300000,
    # "trx_profile_max_count": 10000,
    # "prepared_sql_max": 5001,
    # "debug_prepared_sql": False,
    # "trace_service_name_header_key": None,
    # "trace_service_name_key": None,
    # "web_static_content_extensions": "js, htm, html, gif, png, jpg, css, txt",
    # "trace_auto_service_enabled": False,
    # "trace_auto_service_backstack_enabled": True,
    # "trace_background_socket_enabled": True,
    # "trace_activeserivce_yellow_time": 3000,
    # "trace_activeservice_red_time": 8000,
    # "trace_activeservice_hang_time": 6000,
    # "trace_intertx_enabled": True,
    # "trace_error_callstack_depth": 50,
    # "trace_active_callstack_depth": 50,
    # "_trace_intertx_caller_pcode_key": "x-wtap-pcode",
    # "_trace_intertx_caller_oid_key": "x-wtap-oid",
    # "_trace_intertx_caller_seq_key": "x-wtap-seq",
    # "_trace_intertx_call_url_key": "x-wtap-url",
    # "trace_httpc_normalize_urls": "",
    # "trace_httpc_normalize_enabled": True,
    # "trace_normalize_enabled": True,
    # "log_ignore_set": None,
    # "tcp_connection_timeout": 60000,
    # "tcp_so_timeout": 60000,
    # "net_send_max_bytes": 5 * 1024 * 1024,
    # "net_send_queue1_size": 512,
    # "net_send_queue2_size": 1024,
    # "hook_connection_open_patterns": "",
    # "log_datasource_lookup_enabled": True,
    "throttle_enabled": False,
    "throttle_blocking_url": '',
    "throttle_blocking_ip": '',
    "throttle_blocked_forward": '',
    "throttle_blocked_message": 'request blocked!!',
    "throttle_limit": None,
    "throttle_target_urls": '',
    "throttle_passing_url": '',
    "throttle_passing_url_prefix": '',
    "throttle_rejected_forward": '',
    "throttle_rejected_message": "too many request!!",
    "reject_event_enabled": False,
    # "profile_http_querystring_enabled": False,
    # "profile_http_header_enabled": False,
    # "profile_http_parameter_enabled": False,
    # "profile_http_parameter_url_prefix": "/",
    # "profile_http_header_url_prefix": "/",
    # "profile_connection_open_enabled": True,
    # "profile_step_max_count": 1024,
    # "hook_method_patterns": "",
    # "hook_method_access_public_enabled": True,
    # "hook_method_access_protected_enabled": True,
    # "hook_method_access_private_enabled": False,
    # "hook_method_access_none_enabled": True,
    # "hook_method_ignore_prefixes": "get,set",
    # "hook_method_ignore_classes": "",
    # "profile_method_enabled": True,
    # "hook_service_patterns": "",
    # "hook_httpc_patterns": "",
    # "hook_httpc_info_patterns": "",
    # "hook_jdbc_pstmt_classes": "",
    # "hook_jdbc_stmt_classes": "",
    # "hook_jdbc_rs_classes": "",
    # "hook_jdbc_wrapping_driver_patterns": "",
    # "hook_context_classes": "javax/naming/InitialContext",
    # "hook_jsp_patterns": "",
    # "hook_trace_helper_start_patterns": "",
    # "hook_trace_helper_end_patterns": "",
    # "hook_dyna_ignore_count": 100,
    #
    # "profile_fullstack_max_lines": 0,
    #
    # "profile_step_normal_count": 800,
    # "profile_step_heavy_count": 1000,
    # "profile_step_max_count": 1024,
    # "profile_step_heavy_time": 100,
    #
    # "boolean profile_sql_param_enabled": False,
    # "profile_sql_resource_enabled": False,
    # "profile_method_resource_enabled": False,
    # "profile_httpc_resource_enabled": False,
    # "_profile_prepare_sql": False,
    # "profile_dbc_close": False,
    #
    "trace_http_client_ip_header_key": "",
    # "trace_user_enabled": True,
    # "trace_user_using_ip": False,
    # "trace_user_using_type": 1,
    # "trace_user_cookie_limit": 2048,
    # "profile_error_jdbc_fetch_max": 10000,
    # "profile_error_sql_time_max": 30000,
    # "hook_direct_patch_classes": "",
    # "_hook_serivce_enabled": True,
    # "_hook_dbsql_enabled": True,
    # "_hook_dbconn_enabled": True,
    # "_hook_methods_enabled": True,
    # "_hook_socket_enabled": True,
    # "_hook_usertx_enabled": True,
    # "log_rotation_enabled": True,
    # "log_keep_days": 7,
    # "thread_dump_enabled": False,
    # "debug_cpu_enabled": False,
    # "active_stack_always_do": False,
    # "active_stack_callstack_interval_sec": 10,
    # "realtime_interval_ms": 5000,
    # "cipher_net_enabled": True,
    # "cipher_level": 2,
    # 'cypher_level': 128,
    # "boot_redefine_size": 100,
    # "counter_netstat_enabled": False,
    # "counter_procfd_enabled": False,
    # "counter_interval": 5000,
    # "CONFIG_INITED": False,
    # "_profile_position_httpc_hash": 0,
    # "profile_position_httpc": "",
    # "_profile_position_sql_hash": 0,
    # "profile_position_sql": "",
    # "_profile_position_method_hash": 0,
    # "profile_position_method": "",
    # "profile_position_depth": 50,
    # "time_sync_interval_ms": 300000,
    # "trace_active_transaction_yellow_time": 3000,
    # "trace_active_transaction_red_time": 8000,
    # "trace_active_transaction_hang_time": 30000,
    # "realtime_user_thinktime_max": 300000,
    # "service_port_enabled": False,
    # 'log_pack_data': False,
    # "active_stack_second": 10
    "init_load_interval": 30000,
    "session_read_timeout": 5000,
    "reject_event_interval": 30000,
    "master_agent_host" : "whatap-master-agent.whatap-monitoring.svc.cluster.local",
    "master_agent_port" : 6600,
}
